@@ -1,4 +1,4 @@
-# Copyright 2004-2015 Tom Rothamel <pytom@bishoujo.us>
+# Copyright 2004-2016 Tom Rothamel <pytom@bishoujo.us>
 #
 # Permission is hereby granted, free of charge, to any person
 # obtaining a copy of this software and associated documentation files
@@ -823,7 +823,8 @@ class UseParser(Parser):
         return slast.SLUse(loc, target, args, id_expr, block)
 
 UseParser("use")
-
+Keyword("style_prefix")
+Keyword("style_group")
 
 class TranscludeParser(Parser):
 
@@ -939,6 +940,7 @@ class ScreenParser(Parser):
         screen.zorder = keyword.get("zorder", "0")
         screen.variant = keyword.get("variant", "None")
         screen.predict = keyword.get("predict", "None")
+        screen.layer = keyword.get("layer", "'screens'")
 
         return screen
 
@@ -948,6 +950,8 @@ Keyword("zorder")
 Keyword("variant")
 Keyword("predict")
 Keyword("style_group")
+Keyword("style_prefix")
+Keyword("layer")
 
 def init():
     screen_parser.add(all_statements)
